@@ -23,7 +23,9 @@
 
 #include <config-runtime.h>
 
-#include <fcntl.h>
+#include <cerrno>
+#include <cstring>
+#include <unistd.h>
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QBuffer>
@@ -34,19 +36,6 @@
 #include <QtCore/QString>
 #include <QtCore/QVarLengthArray>
 
-#include <stdlib.h>
-#include <unistd.h>
-#include <errno.h>
-#include <time.h>
-#include <string.h>
-
-#include <arpa/inet.h>
-#include <netinet/in.h>
-
-#include <sys/time.h>
-#include <sys/stat.h>
-#include <sys/types.h>
-
 #include <kapplication.h>
 #include <kuser.h>
 #include <kdebug.h>
@@ -56,20 +45,23 @@
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kurl.h>
-#include <kio/ioslave_defaults.h>
 #include <kmimetype.h>
 #include <kde_file.h>
 #include <kconfiggroup.h>
+#include <kio/ioslave_defaults.h>
 
-#include <libssh/libssh.h>
-#include <libssh/sftp.h>
-#include <libssh/callbacks.h>
-
-#include <cerrno>
 
 #define KIO_SFTP_SPECIAL_TIMEOUT 30
 #define ZERO_STRUCTP(x) do { if ((x) != NULL) memset((char *)(x), 0, sizeof(*(x))); } while(0)
 
+// How big should each data packet be? Definitely not bigger than 64kb or
+// you will overflow the 2 byte size variable in a sftp packet.
+#define MAX_XFER_BUF_SIZE (60 * 1024)
+#define KIO_SFTP_DB 7120
+// Maximum amount of data which can be sent from the KIOSlave in one chunk
+// see TransferJob::slotDataReq (max_size variable) for the value
+#define MAX_TRANSFER_SIZE (14 * 1024 * 1024)
+
 using namespace KIO;
 extern "C"
 {
@@ -195,7 +187,9 @@ int sftpProtocol::auth_callback(const char *prompt, char *buf, size_t len,
 
   info.url.setProtocol("sftp");
   info.url.setHost(mHost);
-  info.url.setPort(mPort);
+  if (mPort > 0 && mPort != DEFAULT_SFTP_PORT) {
+      info.url.setPort(mPort);
+  }
   info.url.setUser(mUsername);
 
   info.comment = "sftp://" + mUsername + "@"  + mHost;
@@ -256,7 +250,9 @@ int sftpProtocol::authenticateKeyboardInteractive(AuthInfo &info) {
 
         infoKbdInt.url.setProtocol("sftp");
         infoKbdInt.url.setHost(mHost);
-        infoKbdInt.url.setPort(mPort);
+        if (mPort > 0 && mPort != DEFAULT_SFTP_PORT) {
+            infoKbdInt.url.setPort(mPort);
+        }
 
         infoKbdInt.caption = i18n("SFTP Login");
         infoKbdInt.comment = "sftp://" + mUsername + "@"  + mHost;
@@ -476,18 +472,7 @@ void sftpProtocol::setHost(const QString& host, quint16 port, const QString& use
   }
 
   mHost = host;
-
-  if (port > 0) {
-    mPort = port;
-  } else {
-    struct servent *pse;
-    if ((pse = getservbyname("ssh", "tcp") ) == NULL) {
-      mPort = 22;
-    } else {
-      mPort = ntohs(pse->s_port);
-    }
-  }
-
+  mPort = port;
   mUsername = user;
   mPassword = pass;
 }
@@ -511,17 +496,19 @@ void sftpProtocol::openConnection() {
   AuthInfo info;
   info.url.setProtocol("sftp");
   info.url.setHost(mHost);
-  info.url.setPort(mPort);
+  if ( mPort > 0 && mPort != DEFAULT_SFTP_PORT ) {
+      info.url.setPort(mPort);
+  }
   info.url.setUser(mUsername);
   info.username = mUsername;
-  const QString origPasswd (mPassword);
 
   // Check for cached authentication info if no password is specified...
   if (mPassword.isEmpty()) {
-    kDebug(KIO_SFTP_DB) << "checking cache: info.username = " << info.username
-                        << ", info.url = " << info.url.prettyUrl();
-
+    kDebug(KIO_SFTP_DB) << "checking cache: info.username =" << info.username
+                        << ", info.url =" << info.url.prettyUrl();
     checkCachedAuthentication(info);
+  } else {
+      info.password = mPassword;
   }
 
   // Start the ssh connection.
@@ -723,11 +710,13 @@ login_start:
       }
     }
 
-    if (!firstTime || mPassword.isEmpty()) {
+    if (!firstTime || info.password.isEmpty()) {
 
       info.keepPassword = true; // make the "keep Password" check box visible to the user.
       info.setModified(false);
 
+      QString username (info.username);
+
       if (firstTime) {
         dlgResult = openPasswordDialog(info);
       } else {
@@ -745,17 +734,12 @@ login_start:
 
       firstTime = false;
 
-      if (!mUsername.isEmpty() && mUsername != info.username) {
-        kDebug(KIO_SFTP_DB) << "Username changed from" << mUsername << "to" << info.username;
+      if (info.isModified() && !username.isEmpty() && username != info.username) {
+        kDebug(KIO_SFTP_DB) << "Username changed from" << username << "to" << info.username;
         info.url.setUser(info.username);
-        mUsername = info.username;
-        mPassword = info.password;
         closeConnection();
         goto login_start;
       }
-
-      mUsername = info.username;
-      mPassword = info.password;
     }
 
     // Try to authenticate with keyboard interactive
@@ -820,7 +804,6 @@ login_start:
   setTimeoutSpecialCommand(KIO_SFTP_SPECIAL_TIMEOUT);
 
   mConnected = true;
-  mPassword = origPasswd;
   connected();
 
   info.password.fill('x');
@@ -2119,8 +2102,9 @@ void sftpProtocol::requiresUserNameRedirection()
     redirectUrl.setUser( mUsername );
     redirectUrl.setPass( mPassword );
     redirectUrl.setHost( mHost );
-    if (mPort > 0)
-      redirectUrl.setPort( mPort );
+    if (mPort > 0 && mPort != DEFAULT_SFTP_PORT) {
+        redirectUrl.setPort( mPort );
+    }
     kDebug(KIO_SFTP_DB) << "redirecting to" << redirectUrl;
     redirection( redirectUrl );
 }
